#
# spec file for package ndctl
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 Intel Corporation
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global gitcommit 46ed7cfc9ade
%define lname libndctl6
%define dname libndctl-devel

Name:           ndctl
Version:        53.1
Release:        2.3
Summary:        Manage "libnvdimm" subsystem devices (Non-volatile Memory)
License:        GPL-2.0
Group:          Hardware/Other
Url:            https://github.com/pmem/ndctl
# Snapshot tarball can be created using: ./make-git-shapshot.sh [gitcommit]
Source0:        %{name}-%{version}.tar.gz
ExclusiveArch:  x86_64

BuildRequires:  asciidoc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libjson-c-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xmlto
BuildRequires:  pkgconfig(libkmod)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(uuid)

%description
Utility library for managing the "libnvdimm" subsystem, used for
platform NVDIMM resources like those defined by the ACPI 6.0 NFIT
(NVDIMM Firmware Interface Table).

%package -n %dname
Summary:        Development files for libndctl
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       %lname = %version-%release

%description -n %dname
Utility library for managing the "libnvdimm" subsystem, which defines
a kernel device model and control message interface for platform
NVDIMM resources like those defined by the ACPI 6.0 NFIT (NVDIMM
Firmware Interface Table).

The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n %lname
Summary:        Management library for "libnvdimm" subsystem devices (Non-volatile Memory)
License:        LGPL-2.1+
Group:          System/Libraries

%description -n %lname
Utility library for managing the "libnvdimm" subsystem, which defines
a kernel device model and control message interface for platform
NVDIMM resources like those defined by the ACPI 6.0 NFIT (NVDIMM
Firmware Interface Table).

%prep
%setup

%build
echo "v%{version}" > version
./autogen.sh
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find "%buildroot" -type f -name "*.la" -delete

%check
make check

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc  licenses/GPLv2 licenses/BSD-MIT licenses/CC0
%{_bindir}/ndctl
%{_mandir}/man1/*
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/completions/ndctl

%files -n %lname
%defattr(-,root,root)
%doc README.md
%doc  COPYING licenses/BSD-MIT licenses/CC0
%{_libdir}/libndctl.so.*
%{_libdir}/libdaxctl.so.*

%files -n %dname
%defattr(-,root,root)
%doc  COPYING
%{_includedir}/ndctl/
%{_libdir}/libndctl.so
%{_libdir}/pkgconfig/libndctl.pc
%{_includedir}/daxctl/
%{_libdir}/libdaxctl.so
%{_libdir}/pkgconfig/libdaxctl.pc

%changelog
* Tue Jun 21 2016 jthumshirn@suse.com
- Fix rpmbuild failure on factory
* Mon May 30 2016 jthumshirn@suse.com
- Update to v53.1
  This release incorporates the capabilities of the 4.7-rc1 kernel (most
  prominently in that kernel 'Device DAX', DAX error handling, and
  third-party DSM support).  The ndctl updates include:
  New commands / options:
    bash completion for ndctl commands
    DIMM SMART data retrieval (ndctl list --dimms --health)
    ndctl destroy-namespace
    ndctl read-labels
  New tests:
    DAX error handling unit test (dax-errors.sh)
  Command fixes:
    ndctl list
    ndctl create-namespace
  New apis:
    ndctl_cmd_smart_get_alarm_flags
    ndctl_cmd_smart_get_flags
    ndctl_cmd_smart_get_health
    ndctl_cmd_smart_get_life_used
    ndctl_cmd_smart_get_shutdown_state
    ndctl_cmd_smart_get_spares
    ndctl_cmd_smart_get_temperature
    ndctl_cmd_smart_get_vendor_data
    ndctl_cmd_smart_get_vendor_size
    ndctl_cmd_smart_threshold_get_alarm_control
    ndctl_cmd_smart_threshold_get_spares
    ndctl_cmd_smart_threshold_get_temperature
    ndctl_dax_delete
    ndctl_dax_enable
    ndctl_dax_get_align
    ndctl_dax_get_bus
    ndctl_dax_get_ctx
    ndctl_dax_get_daxctl_region
    ndctl_dax_get_devname
    ndctl_dax_get_first
    ndctl_dax_get_id
    ndctl_dax_get_location
    ndctl_dax_get_namespace
    ndctl_dax_get_next
    ndctl_dax_get_region
    ndctl_dax_get_resource
    ndctl_dax_get_size
    ndctl_dax_get_uuid
    ndctl_dax_is_configured
    ndctl_dax_is_enabled
    ndctl_dax_is_valid
    ndctl_dax_set_align
    ndctl_dax_set_location
    ndctl_dax_set_namespace
    ndctl_dax_set_uuid
    ndctl_dimm_cmd_new_smart
    ndctl_dimm_cmd_new_smart_threshold
    ndctl_dimm_get_formatN
    ndctl_dimm_get_formats
    ndctl_dimm_get_subsystem_device
    ndctl_dimm_get_subsystem_revision
    ndctl_dimm_get_subsystem_vendor
    ndctl_dimm_get_unique_id
    ndctl_get_daxctl_ctx
    ndctl_namespace_get_dax
    ndctl_namespace_get_dax
    ndctl_region_get_dax_seed
    daxctl_dev_get_devname
    daxctl_dev_get_first
    daxctl_dev_get_id
    daxctl_dev_get_major
    daxctl_dev_get_minor
    daxctl_dev_get_next
    daxctl_dev_get_region
    daxctl_dev_get_size
    daxctl_get_log_priority
    daxctl_get_userdata
    daxctl_new
    daxctl_new_region
    daxctl_ref
    daxctl_region_get_ctx
    daxctl_region_get_id
    daxctl_region_get_uuid
    daxctl_region_ref
    daxctl_region_unref
    daxctl_region_unref
    daxctl_set_log_fn
    daxctl_set_log_priority
    daxctl_set_userdata
    daxctl_unref
* Wed Apr 27 2016 jthumshirn@suse.com
- NVDIMM is not defined for any CPU architecture other than x86_64 at the
  moment.
* Sun Apr 24 2016 jengelh@inai.de
- RPM group and description update
* Wed Mar 30 2016 jthumshirn@suse.com
- Update to v52
  This release incorporates the capabilities of the 4.6 kernel (most
  prominently 'clear poison' support), and adds the below features and
  fixes:
  New apis:
  ndctl_invalidate
  ndctl_cmd_ars_cap_get_range
  ndctl_bus_cmd_new_clear_error
  ndctl_cmd_clear_error_get_cleared
  ndctl_namespace_get_resource
  ndctl_pfn_get_size
  ndctl_pfn_get_resource
  Api fixes:
  ndctl_bus_cmd_new_ars_status - output buffer sizing fix
  ndctl_bus_cmd_new_ars_status - input validation
  ndctl_cmd_ars_in_progress - invalidate state after checking
* Wed Mar  2 2016 jthumshirn@suse.com
- Update to v51
  This release reworks spec file generation to use automated tarballs
  generated by github for each annotated tag. It also includes a couple of
  minor fixes.
* Wed Feb  3 2016 kkaempf@suse.com
- Update to v50
  This release incorporates the capabilities of the 4.5 kernel,
  and adds the below features and fixes:
  New apis:
  ndctl_bus_get_ctx
  ndctl_namespace_get_pfn
  ndctl_namespace_get_mode
  ndctl_namespace_get_numa_node
  ndctl_region_get_pfn_seed
  ndctl_pfn_get_first
  ndctl_pfn_get_next
  ndctl_pfn_get_id
  ndctl_pfn_get_namespace
  ndctl_pfn_get_uuid
  ndctl_pfn_set_uuid
  ndctl_pfn_get_location
  ndctl_pfn_set_location
  ndctl_pfn_get_align
  ndctl_pfn_set_align
  ndctl_pfn_set_namespace
  ndctl_pfn_get_bus
  ndctl_pfn_get_ctx
  ndctl_pfn_get_devname
  ndctl_pfn_get_block_device
  ndctl_pfn_is_valid
  ndctl_pfn_is_enabled
  ndctl_pfn_get_region
  ndctl_pfn_enable
  ndctl_pfn_delete
  ndctl_pfn_is_configured
  New utility commands:
  list
  help (man pages)
  create-namespace
  Api fixes:
  ndctl_{namespace|btt}_foreach crash fix
  ndctl_namespace_delete no longer errors on "io" namespaces
  miscellaneous static analysis fixes
  Utility command fixes:
  {en|dis}able-{namespace|region} return code
* Thu Sep 10 2015 dan.j.williams@intel.com
- updates for the new versioning scheme introduced with v47
- synchronized the spec file with the one produced by contrib/genspec
* Wed Aug  5 2015 meissner@suse.com
- cleaned up spec file. added licenses. added make check
* Wed Aug  5 2015 dan.j.williams@intel.com
- Management library for "libnvdimm" subsystem devices (Non-volatile Memory)
